# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'new.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(182, 141)
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setGeometry(QtCore.QRect(10, 10, 47, 13))
        self.label.setObjectName("label")
        self.nameEdit = QtWidgets.QLineEdit(Dialog)
        self.nameEdit.setGeometry(QtCore.QRect(10, 30, 161, 20))
        self.nameEdit.setObjectName("nameEdit")
        self.label_2 = QtWidgets.QLabel(Dialog)
        self.label_2.setGeometry(QtCore.QRect(10, 60, 171, 16))
        self.label_2.setObjectName("label_2")
        self.extEdit = QtWidgets.QLineEdit(Dialog)
        self.extEdit.setGeometry(QtCore.QRect(10, 80, 161, 20))
        self.extEdit.setToolTip("")
        self.extEdit.setObjectName("extEdit")
        self.cancelButton = QtWidgets.QPushButton(Dialog)
        self.cancelButton.setGeometry(QtCore.QRect(10, 110, 75, 23))
        self.cancelButton.setAutoDefault(False)
        self.cancelButton.setObjectName("cancelButton")
        self.acceptButton = QtWidgets.QPushButton(Dialog)
        self.acceptButton.setGeometry(QtCore.QRect(100, 110, 75, 23))
        self.acceptButton.setAutoDefault(False)
        self.acceptButton.setObjectName("acceptButton")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "New"))
        self.label.setText(_translate("Dialog", "Name:"))
        self.nameEdit.setPlaceholderText(_translate("Dialog", "Example: Installers"))
        self.label_2.setText(_translate("Dialog", "Extensions (separated by ;)"))
        self.extEdit.setPlaceholderText(_translate("Dialog", "Example: exe; msi;"))
        self.cancelButton.setText(_translate("Dialog", "Calcel"))
        self.acceptButton.setText(_translate("Dialog", "Accept"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())
